@@ -58,7 +58,7 @@ SearchWidget::SearchWidget(QWidget *parent)
     QVBoxLayout *layout = new QVBoxLayout(this);
 
     QHBoxLayout *hbox = new QHBoxLayout;
-    hbox->addWidget(new QLabel(QStringLiteral("Search store:")), 0, 0);
+    hbox->addWidget(new QLabel(QStringLiteral("Search store:")), 0, {});
     mStoreCombo = new KComboBox;
     mStoreCombo->setObjectName(QStringLiteral("SearchStoreCombo"));
     hbox->addWidget(mStoreCombo);
@@ -117,7 +117,11 @@ SearchWidget::SearchWidget(QWidget *parent)
 
     connect(button, &QPushButton::clicked, this, &SearchWidget::search);
     connect(mDatabaseView, &QListView::activated, this, &SearchWidget::fetchItem);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mStoreCombo, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &SearchWidget::openStore);
+#else
+    connect(mStoreCombo, QOverload<int, const QString &>::of(&KComboBox::currentIndexChanged), this, &SearchWidget::openStore);
+#endif
 
     openStore(0);
 
